library(gnlm)
library(repeated)
library(event)

aircraft <- read.list("aircraft.dat",skip=4,nline=1)
raircraft <- list()
for(i in aircraft)raircraft <- c(raircraft,list(cbind(1/i,1/i^2)))
# need censor because event times
cens <- rep(1,13)
raircraft <- restovec(raircraft,cens=cens)
aircraft <- restovec(aircraft,cens=cens)

if(interactive()){
postscript("aircraft.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
cprocess(aircraft,number=T,ylim=c(0,32),xlab="Total hours",yaxt="n",
	ylab="Number of failures")
axis(2,c(0,10,20,30))
dev.off()
}

craft <- as.factor(covind(aircraft))
mu <- function(p,linear) exp(linear)
shape <- function(p,linear) linear

print(se <- gnlr(aircraft,"exponential",pmu=100))
print(re <- gnlr(aircraft,"exp",pmu=c(10,rep(0,12)),mu=mu,linear=~craft))

print(sw <- gnlr(aircraft,"Weibull",pmu=100,psh=1))
print(rw <- gnlr(aircraft,"Weibull",pmu=c(10,rep(0,12)),psh=1,mu=mu,
	linear=~craft,iter=200))
print(aw <- gnlr(aircraft,"Weibull",pmu=220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(bw <- gnlr(aircraft,"Weibull",pmu=c(10,rep(0,12)),psh=c(1,rep(0,12)),
	mu=mu,shape=shape,linear=list(~craft,~craft),iter=200))

print(sg <- gnlr(aircraft,"gamma",pmu=100,psh=1))
print(rg <- gnlr(aircraft,"gamma",pmu=c(10,rep(0,12)),psh=1,mu=mu,
	linear=~craft,iter=200))
print(ag <- gnlr(aircraft,"gamma",pmu=220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(bg <- gnlr(aircraft,"gamma",pmu=c(10,rep(0,12)),psh=c(1,rep(0,12)),mu=mu,
	shape=shape,linear=list(~craft,~craft),iter=200))

print(sig <- gnlr(aircraft,"inverse Gauss",pmu=100,psh=1))
print(rig <- gnlr(aircraft,"inverse Gauss",pmu=c(10,rep(0,12)),psh=1,mu=mu,
	linear=~craft,iter=200))
print(aig <- gnlr(aircraft,"inverse Gauss",pmu=220,psh=c(1,rep(0,12)),
	shape=shape,linear=list(NULL,~craft)))
print(big <- gnlr(aircraft,"inverse Gauss",pmu=c(10,rep(0,12)),
	psh=c(1,rep(0,12)),mu=mu,shape=shape,linear=list(~craft,~craft),
	iter=200))

print(srg <- gnlr(raircraft,"gamma",pmu=1/100,psh=1))
print(rrg <- gnlr(raircraft,"gamma",pmu=c(10,rep(0,12)),psh=1,mu=mu,
	linear=~craft,iter=200))
print(arg <- gnlr(raircraft,"gamma",pmu=1/220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(brg <- gnlr(raircraft,"gamma",pmu=c(-3,rep(0,12)),psh=c(-1,rep(1,12)),
	mu=mu,shape=shape,linear=list(~craft,~craft),iter=200))

print(srig <- gnlr(raircraft,"inverse Gauss",pmu=1/10,psh=4))
print(rrig <- gnlr(raircraft,"inverse Gauss",pmu=c(-3.5,rep(0,12)),psh=4,mu=mu,
	linear=~craft,iter=200))
exp(-rrig$coef[1]-c(0,rrig$coef[2:13]))
print(arig <- gnlr(raircraft,"inverse Gauss",pmu=1/220,psh=c(1,rep(0,12)),
	shape=shape,linear=list(NULL,~craft)))
print(brig <- gnlr(raircraft,"inverse Gauss",pmu=c(-3,rep(0,12)),iter=200,
	psh=c(-1,rep(0,12)),mu=mu,shape=shape,linear=list(~craft,~craft)))

# must take reciprocal to get the means right, as compared to rrig
print(rgig <- gnlr3(raircraft,"inverse Gauss",pmu=c(-3.7,rep(0,12)),psh=1,
	pfam=1,mu=mu,linear=~craft,iter=200))
exp(-c(rgig$coef[1],rgig$coef[1]+rgig$coef[2:13]))
 
if(interactive()){
postscript("air2.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
nobs <- cumsum(nobs(aircraft))
tt <- seq(10,max(response(aircraft)[1:nobs[1]]),by=10)
plot(tt,dinvgauss(1/tt,exp(rrig$coeff[1]),exp(rrig$coef[14]))/tt^2/
	pinvgauss(1/tt,exp(rrig$coeff[1]),exp(rrig$coef[14])),xaxt="n",
	type="l",xlim=c(0,650),ylim=c(0,0.02),
	xlab="Hours since last failure",ylab="Intensity")
axis(1,c(0,200,400,600))
for(i in 2:13){
	tt <- seq(10,max(response(aircraft)[(nobs[i-1]+1):nobs[i]]),by=10)
	lines(tt,dinvgauss(1/tt,exp(rrig$coeff[1]+rrig$coeff[i]),
		exp(rrig$coef[14]))/tt^2/pinvgauss(1/tt,exp(rrig$coeff[1]+
		rrig$coeff[i]),exp(rrig$coef[14])))}
# because of reciprocal, must use pinvgauss, not 1-pinvgauss, for survival
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(1))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[2]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(2))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[3]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(3))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[4]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(4))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[5]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(5))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[11]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(11))
text(30,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[13]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(13))
dev.off()
}

gnlmm(raircraft,"inverse Gauss",pmu=0.05,psh=4,nest=craft,points=11,psd=0.2)
gnlmm(raircraft,"inverse Gauss",pmu=0.054,psh=4,nest=craft,points=11,psd=0.1,
	scale="identity")
