library(gnlm)
library(repeated)
library(event)

aircraft <- read.list("aircraft.dat",skip=4,nline=1)
cens <- rep(1,13)
aircraft <- restovec(aircraft,cens=cens)

if(interactive()){
postscript("aircraft.eps",width=5,height=5)
cprocess(aircraft,number=T,ylim=c(0,32),xlab="Days",ylab="Number of failures")
}

print(ze <- kalsurv(aircraft,pinit=1.5,preg=4,dep="frailty"))
print(zeb <- kalsurv(aircraft,pinit=1.5,preg=8,pbirth=0,dep="frailty"))
print(zw <- kalsurv(aircraft,pinit=1.5,preg=8,psh=1,
	intensity="Weibull",dep="frailty"))
print(zwb <- kalsurv(aircraft,pinit=1.5,preg=8,psh=1,
	intensity="Weibull",pbirth=0,dep="frailty"))
print(zg <- kalsurv(aircraft,pinit=.09,preg=8,psh=1,
	intensity="gamma",dep="frailty"))
print(zgb <- kalsurv(aircraft,pinit=0.1,preg=8,psh=1,
	intensity="gamma",pbirth=0,dep="frailty"))
print(zln <- kalsurv(aircraft,pinit=.09,preg=4,psh=1,
	intensity="log normal",dep="frailty"))
print(zlnb <- kalsurv(aircraft,pinit=0.1,preg=4,psh=1,
	intensity="log normal",pbirth=0,dep="frailty"))

print(zei <- kalsurv(aircraft,pinit=0.1,preg=6,dep="independence"))
print(zee <- kalsurv(aircraft,pinit=0.1,pdep=0.5,preg=6,
	dep="serial",upd="event"))
print(zes <- kalsurv(aircraft,pinit=0.01,pdep=0.8,preg=7,
	dep="serial",upd="Markov"))
print(zec <- kalsurv(aircraft,pinit=0.1,pdep=0.9,preg=7,
	dep="serial",upd="count"))
print(zeh <- kalsurv(aircraft,pinit=0.1,pdep=0.9,preg=7,
	dep="serial",upd="cumulated"))
print(zek <- kalsurv(aircraft,pinit=0.2,pdep=0.9,preg=7,
	dep="serial",upd="kalman"))
print(zek <- kalsurv(aircraft,pinit=1,pdep=0.9,preg=6.9,
	dep="serial",upd="Markov",renew=F))

print(zwi <- kalsurv(aircraft,pinit=0.7,preg=8,psh=1,
	intensity="Weibull",dep="independence"))
print(zwe <- kalsurv(aircraft,pinit=0.7,pdep=0.5,preg=8,psh=1,
	intensity="Weibull",dep="serial",upd="event"))
print(zws <- kalsurv(aircraft,pinit=0.7,pdep=0.5,preg=8,psh=1,
	intensity="Weibull",dep="serial",upd="Markov"))
print(zwc <- kalsurv(aircraft,pinit=0.7,pdep=0.5,preg=8,psh=1,
	intensity="Weibull",dep="serial",upd="count"))
print(zwh <- kalsurv(aircraft,pinit=0.7,pdep=0.5,preg=8,psh=1,
	intensity="Weibull",dep="serial",upd="cumulated"))
print(zwk <- kalsurv(aircraft,pinit=0.005,pdep=0.5,preg=8,psh=1,
	intensity="Weibull",dep="serial",upd="kalman"))

print(zgi <- kalsurv(aircraft,pinit=0.2,preg=7,psh=1,
	intensity="gamma",dep="independence"))
print(zgs <- kalsurv(aircraft,pinit=0.2,pdep=0.3,preg=7,psh=1,
	intensity="gamma",dep="serial",upd="Markov"))
print(zlni <- kalsurv(aircraft,pinit=0.1,preg=7,psh=1.5,
	intensity="log normal",dep="independence"))
print(zlns <- kalsurv(aircraft,pinit=0.1,pdep=0.9,preg=7,psh=1.5,
	intensity="log normal",dep="serial",upd="Markov"))

y <- response(aircraft)
craft <- as.factor(rep(1:13,nobs(aircraft)))
print(se <- gnlr(y,"exponential",pmu=100))
print(sg <- gnlr(y,"gamma",pmu=100,psh=1))
print(sw <- gnlr(y,"Weibull",pmu=100,psh=1))
print(sig <- gnlr(y,"inverse Gauss",pmu=100,psh=1))
print(srg <- gnlr(1/y,"gamma",pmu=1/100,psh=1,delta=1/y^2))
print(srw <- gnlr(1/y,"Weibull",pmu=1/100,psh=1,delta=1/y^2))
print(srig <- gnlr(1/y,"inverse Gauss",pmu=1/10,psh=4,delta=1/y^2))
print(sln <- gnlr(log(y),"normal",pmu=1/10,psh=1,delta=1/y))

birth <- log(sequence(nobs(aircraft)))
mu <- function(p) exp(p[1]+p[2]*birth)
print(tg <- gnlr(y,"gamma",pmu=c(100,0),psh=1,mu=mu))
print(tw <- gnlr(y,"Weibull",pmu=c(100,0),psh=1,mu=mu))

mu <- function(p,linear) exp(linear)
print(re <- gnlr(y,"exp",pmu=c(10,rep(0,12)),mu=mu,linear=~craft))
print(rg <- gnlr(y,"gamma",pmu=c(10,rep(0,12)),psh=1,mu=mu,linear=~craft))
print(rw <- gnlr(y,"Weibull",pmu=c(10,rep(0,12)),psh=1,mu=mu,linear=~craft))
print(rig <- gnlr(y,"inverse Gauss",pmu=c(10,rep(0,12)),psh=1,mu=mu,
	linear=~craft))
print(rrg <- gnlr(1/y,"gamma",pmu=c(10,rep(0,12)),psh=1,mu=mu,linear=~craft,
	delta=1/y^2))
print(rrig <- gnlr(1/y,"inverse Gauss",pmu=c(-3.5,rep(0,12)),psh=4,mu=mu,
	linear=~craft,delta=1/y^2,iter=200))
exp(-rrig$coef[1]-c(0,rrig$coef[2:13]))

if(interactive()){
postscript("air2.eps",width=5,height=5)
nobs <- cumsum(nobs(aircraft))
tt <- seq(10,max(y[1:nobs[1]]),by=10)
plot(tt,dinvgauss(1/tt,exp(rrig$coeff[1]),exp(rrig$coef[14]))/tt^2/
	pinvgauss(1/tt,exp(rrig$coeff[1]),exp(rrig$coef[14])),
	type="l",xlim=c(0,650),ylim=c(0,0.02),xlab="Hours",ylab="Intensity")
for(i in 2:13){
tt <- seq(10,max(y[(nobs[i-1]+1):nobs[i]]),by=10)
lines(tt,dinvgauss(1/tt,exp(rrig$coeff[1]+rrig$coeff[i]),exp(rrig$coef[14]))/
	tt^2/pinvgauss(1/tt,exp(rrig$coeff[1]+rrig$coeff[i]),exp(rrig$coef[14])))}
# because of reciprocal, must use pinvgauss, not 1-pinvgauss, for survival
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(1))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[2]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(2))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[3]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(3))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[4]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(4))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[5]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(5))
text(-5,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[11]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(11))
text(30,dinvgauss(0.1,exp(rrig$coeff[1]+rrig$coeff[13]),exp(rrig$coef[14]))/10^2/
	pinvgauss(0.1,exp(rrig$coeff[1]),exp(rrig$coef[14])),label=paste(13))
}

shape <- function(p,linear) linear
print(ag <- gnlr(y,"gamma",pmu=220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(aw <- gnlr(y,"Weibull",pmu=220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(aig <- gnlr(y,"inverse Gauss",pmu=220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft)))
print(arg <- gnlr(1/y,"gamma",pmu=1/220,psh=c(1,rep(0,12)),shape=shape,
	linear=list(NULL,~craft),delta=1/y^2))
print(arig <- gnlr(1/y,"inverse Gauss",pmu=1/220,psh=c(1,rep(0,12)),
	shape=shape,linear=list(NULL,~craft),delta=1/y^2))

print(bg <- gnlr(y,"gamma",pmu=c(10,rep(0,12)),psh=c(1,rep(0,12)),mu=mu,
	shape=shape,linear=list(~craft,~craft)))
print(bw <- gnlr(y,"Weibull",pmu=c(10,rep(0,12)),psh=c(1,rep(0,12)),mu=mu,
	shape=shape,linear=list(~craft,~craft)))
print(big <- gnlr(y,"inverse Gauss",pmu=c(10,rep(0,12)),psh=c(1,rep(0,12)),
	mu=mu,shape=shape,linear=list(~craft,~craft)))
print(brg <- gnlr(1/y,"gamma",pmu=c(-3,rep(0,12)),psh=c(-1,rep(1,12)),mu=mu,
	shape=shape,linear=list(~craft,~craft),delta=1/y^2))
print(brig <- gnlr(1/y,"inverse Gauss",pmu=c(-3,rep(0,12)),delta=1/y^2,
	psh=c(-1,rep(0,12)),mu=mu,shape=shape,linear=list(~craft,~craft)))

print(gig <- gnlr3(y,"inverse Gauss",pmu=c(0.86,rep(0,12)),psh=-1.52,pfam=0.8,
	mu=mu,linear=~craft))
# must take reciprocal to get the means right, as compared to rrig
print(rgig <- gnlr3(1/y,"inverse Gauss",pmu=c(-3.7,rep(0,12)),psh=1,
	pfam=1,mu=mu,linear=~craft,delta=1/y^2,iter=200))
exp(-c(rgig$coef[1],rgig$coef[1]+rgig$coef[2:13]))
print(gg <- gnlr3(y,"gamma",pmu=c(1,rep(0,12)),psh=1,pfam=0.11,
	mu=mu,linear=~craft))
print(gev <- gnlr3(y,"extreme",pmu=c(-8.1,rep(0,12)),psh=0.34,pfam=-0.084,
	mu=mu,linear=~craft))

gnlmm(y,"exponential",pmu=93,nest=craft,points=3,psd=0.2)
gnlmm(1/y,"inverse Gauss",pmu=0.05,psh=4,delta=1/y^2,
	nest=craft,points=3,psd=0.2)
gnlmm(1/y,"inverse Gauss",pmu=0.05,psh=4,delta=1/y^2,
	nest=craft,points=3,psd=0.1,scale="identity")

# number of unique uncensored observations = 130
length(unique(response(aircraft)))

# number of ties = 0
sum(response(aircraft)==0)

# number censored/number = 0/13
length(cens)-sum(cens)
length(cens)
