library(gnlm)
library(event)

data <- read.table("gallston.dat",skip=5,head=T)
attach(data)

Chol <- Chol-Pain
y <- as.vector(t(cbind(Pain,Chol)))
state <- c(rep(c(0,1),48),rep(c(0,1),65))[y>0]
treat <- c(rep(0,48*2),rep(1,2*65))[y>0]
y <- cbind(y[y>0],c(t(cbind(Cen.pain,Cen.chol)))[y>0])

mu <- function(mu,linear) exp(linear)
gnlr3(y,"extreme",mu=mu,linear=list(~treat,~treat,~state),
	pmu=c(-2.7,0.2),psh=c(0.38,0.5),pfam=c(-0.14,0))
gnlr3(y,"extreme",mu=mu,linear=list(~treat,~treat,~treat),
	pmu=c(-2.81,0.0024),psh=c(0.37,0.45),pfam=c(-0.137,0.0037))
print(z <- gnlr(y,"Weibull",mu=mu,linear=list(~treat,~treat),
	pmu=c(7,0),psh=c(-0.2,0)))
gnlr(y,"exp",mu=mu,linear=~treat,pmu=c(7,0))
gnlr(y,"Weibull",mu=mu,linear=~treat,pmu=c(7,0),psh=-0.2)
print(z0 <- gnlr(y,"Weibull",linear=list(NULL,~treat),pmu=1200,
	psh=c(-0.2,0)))


if(interactive()){
times <- seq(1,1000,by=10)
postscript("gallst.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(y[,1],y[,2],2*treat+state),xlim=c(0,1000),main="",xlab="Days",
	ylab="Survival function")
lines(times,1-pweibull(times,exp(z0$coef[2]),z0$coef[1]))
lines(times,1-pweibull(times,exp(z0$coef[2]+z0$coef[3]),z0$coef[1]),lty=3)
legend(0,0.45,legend=c("Time to pain","Placebo","Chenodiol",
	"Time to cholecystectomy","Placebo","Chenodiol"),lty=c("",1,3,"",2,4),
	bty="n")
wintensity <- function(y,lambda,beta) lambda*(y/beta)^(lambda-1)/beta
plot(times,wintensity(times,exp(z0$coef[2]),z0$coef[1]),type="l",
	ylim=c(0,0.006),xlab="Days",ylab="Intensity of events",yaxt="n")
axis(2,c(0,0.002,0.004,0.006))
lines(times,wintensity(times,exp(z0$coef[2]+z0$coef[3]),
	z0$coef[1]),lty=2)
dev.off()
}
