library(gnlm)
library(event)

data <- read.table("gallston.dat",skip=5,head=T)
attach(data)

Chol <- Chol-Pain
y <- as.vector(t(cbind(Pain,Chol)))
state <- c(rep(c(0,1),48),rep(c(0,1),65))[y>0]
cens <- c(t(cbind(Cen.pain,Cen.chol)))[y>0]
treat <- c(rep(0,48*2),rep(1,2*65))[y>0]
y <- y[y>0]

mu <- function(mu,linear) exp(linear)
gnlr3(cbind(y,cens),"extreme",pmu=0.01,psh=0.34,pfam=-0.1)

gnlr3(cbind(y,cens),"extreme",mu=mu,linear=~state,pmu=c(-5.1,0.2),psh=0.32,
	pfam=-0.1)
gnlr3(cbind(y,cens),"extreme",mu=mu,linear=~treat,pmu=c(-5.1,0),psh=0.32,
	pfam=-0.1)

gnlr3(cbind(y,cens),"extreme",mu=mu,linear=list(~treat,~state,NULL),
	pmu=c(-5.1,0),psh=c(0.32,0),pfam=-0.1)
gnlr3(cbind(y,cens),"extreme",mu=mu,linear=list(~treat,~treat,NULL),
	pmu=c(-5.1,0),psh=c(0.32,0),pfam=-0.1)

gnlr3(cbind(y,cens),"extreme",mu=mu,linear=list(~treat,~treat,~state),
	pmu=c(-2.7,0.2),psh=c(0.38,0.5),pfam=c(-0.14,0))
gnlr3(cbind(y,cens),"extreme",mu=mu,linear=list(~treat,~treat,~treat),
	pmu=c(-2.81,0.0024),psh=c(0.37,0.45),pfam=c(-0.137,0.0037))

gnlr(cbind(y,cens),"Weibull",pmu=1200,psh=-0.2)
gnlr(cbind(y,cens),"Weibull",mu=mu,linear=~treat,pmu=c(7,0),psh=-0.2)
print(z0 <- gnlr(cbind(y,cens),"Weibull",linear=list(NULL,~treat),pmu=1200,
	psh=c(-0.2,0)))
print(z <- gnlr(cbind(y,cens),"Weibull",mu=mu,linear=list(~treat,~treat),
	pmu=c(7,0),psh=c(-0.2,0)))
print(z1 <- gnlr(cbind(y,cens),"Weibull",mu=mu,
	linear=list(~treat+state,~treat),pmu=c(7,0,0),psh=c(-0.2,0)))
print(z1a <- gnlr(cbind(y,cens),"Weibull",mu=mu,
	linear=list(~treat*state,~treat),pmu=c(7,0,0,0),psh=c(-0.2,0)))
print(z2 <- gnlr(cbind(y,cens),"Weibull",mu=mu,
	linear=list(~treat,~treat+state),pmu=c(7,0),psh=c(-0.2,0,0)))
print(z2a <- gnlr(cbind(y,cens),"Weibull",mu=mu,
	linear=list(~treat,~treat*state),pmu=c(7,0),psh=c(-0.2,0,0,0)))

gnlr(cbind(y,cens),"exp",mu=mu,linear=~treat,pmu=c(7,0))

print(z0g <- gnlr(cbind(y,cens),"gamma",linear=list(NULL,~treat),pmu=1200,
	psh=c(-0.2,0)))
print(z0ln <- gnlr(cbind(log(y),cens),"normal",linear=list(NULL,~treat),
	pmu=6,psh=c(1.6,0),delta=1/y))
print(z1ln <- gnlr(cbind(log(y),cens),"normal",linear=list(~treat,~treat),
	pmu=c(6,0),psh=c(1.6,0),delta=1/y))

if(interactive()){
times <- seq(1,1000,by=10)
postscript("gallst.eps",height=5)
par(mfrow=c(1,2))
plot(km(y,cens,2*treat+state),xlim=c(0,1000),main="",xlab="Days",
	ylab="Survival function")
#lines(times,1-pweibull(times,exp(z$coef[3]),exp(z$coef[1])))
#lines(times,1-pweibull(times,exp(z$coef[3]+z$coef[4]),
#	exp(z$coef[1]+z$coef[2])),lty=3)
lines(times,1-pweibull(times,exp(z0$coef[2]),z0$coef[1]))
lines(times,1-pweibull(times,exp(z0$coef[2]+z0$coef[3]),z0$coef[1]),lty=3)
#lines(times,1-pnorm(log(times),z1ln$coef[1],exp(z1ln$coef[3]/2)))
#lines(times,1-pnorm(log(times),z1ln$coef[1]+z1ln$coef[2],
#	exp((z1ln$coef[3]+z1ln$coef[4])/2)),lty=3)
wintensity <- function(y,lambda,beta) lambda*(y/beta)^(lambda-1)/beta
#plot(times,wintensity(times,exp(z$coef[3]),exp(z$coef[1])),type="l",
#	ylim=c(0,0.006),xlab="Days",ylab="Intensity of events")
#lines(times,wintensity(times,exp(z$coef[3]+z$coef[4]),
#	exp(z$coef[1]+z$coef[2])),lty=3)
plot(times,wintensity(times,exp(z0$coef[2]),z0$coef[1]),type="l",
	ylim=c(0,0.006),xlab="Days",ylab="Intensity of events")
lines(times,wintensity(times,exp(z0$coef[2]+z0$coef[3]),
	z0$coef[1]),lty=2)
#plot(times,dnorm(log(times),z1ln$coef[1],exp(z1ln$coef[3]/2))/
#	(1-pnorm(log(times),z1ln$coef[1],exp(z1ln$coef[3]/2)))/times,type="l",
#	ylim=c(0,0.006),xlab="Days",ylab="Intensity of events")
#lines(times,dnorm(log(times),z1ln$coef[1]+z1ln$coef[2],
#	exp((z1ln$coef[3]+z1ln$coef[3])/2))/(1-pnorm(log(times),
#	z1ln$coef[1]+z1ln$coef[2],exp((z1ln$coef[3]+z1ln$coef[3])/2)))/times,
#	lty=2)
}
