library(gnlm)
library(event)
library(repeated)

y <- read.table("grafts.dat",skip=5)
attach(y)
resp <- cbind(y[,1],y[,3])
censor <- cbind(y[,2],y[,4])
yy <- cbind(c(y[,1],y[,3]),c(y[,2],y[,4]))
lyy  <- cbind(log(c(y[,1],y[,3])),c(y[,2],y[,4]))
burn <- rep(y[,5],2)

# Different intensity functions
print(zcr <- coxre(resp,censor,1:11,est=0.1,stratified=T))
coxre(resp,censor,1:11,est=0.1,cov=y[,5],stratified=T)
# Proportional intensity functions
coxre(resp,censor,1:11,est=0.1,stratified=F)
coxre(resp,censor,1:11,est=0.1,stratified=F,cov=y[,5])
# Identical intensity functions
coxre(as.vector(t(resp)),as.vector(t(censor)),rep(1:11,rep(2,11)),est=0.1)

resp <- restovec(resp,censor=censor)

mu <- function(p,linear) exp(linear)
matches <- gl(2,11,22)
gnlr(yy, "exponential", mu=mu, linear=~matches+burn,
	pmu=c(3,-1,0))
gnlr(yy, "Weibull", mu=mu, linear=~1, pmu=4, psh=0.5)
print(zw <- gnlr(yy, "Weibull", mu=mu, linear=~matches,
	pmu=c(4,2), psh=0.5))
print(zw2 <- gnlr(yy, "Weibull", mu=mu, linear=~matches+burn,
	pmu=c(3,-0.5,0), psh=0.5))
gnlr(yy, "Weibull", mu=mu, linear=~matches,
	shape=~matches, pmu=c(4,2), psh=c(0.5,0))
gnlr(yy, "Weibull", mu=mu, linear=~matches+burn,
	shape=~matches, pmu=c(4,2,0), psh=c(0.5,0))
print(zn <- gnlr(lyy, "normal", mu=~matches,
	pmu=c(4,2), psh=0.5, delta=1/c(y[,1],y[,3])))
print(zn2 <- gnlr(lyy, "normal", mu=~matches+burn,
	pmu=c(4,2,0), psh=0.5, delta=1/c(y[,1],y[,3])))
gnlr(lyy, "normal", mu=~matches, shape=~matches,
	pmu=c(4,2), psh=c(-1,0), delta=1/c(y[,1],y[,3]))
gnlr(lyy, "normal", mu=~matches+burn,
	shape=~matches, pmu=c(4,2,0), psh=c(-1,0), delta=1/c(y[,1],y[,3]))
gnlr(yy, "inverse Gauss", mu=mu, linear=~matches,
	pmu=c(4,-0.6), psh=-5)
gnlr(yy, "inverse Gauss", mu=mu, linear=~matches+burn,
	pmu=c(4,-0.6,0), psh=-5)
gnlr3(yy, "inverse", mu=mu, linear=~matches, pmu=c(7.5,-4),
	  psh=-5,pfam=-2.6)
gnlr3(yy, "inverse", mu=mu, linear=~matches+burn, pmu=c(7.5,-4,0.01),
	  psh=-5,pfam=-2.6)
#gnlr3(lyy, "power exp", mu=~matches, pmu=c(7.5,-4),
#	  psh=-1,pfam=-2, delta=1/c(y[,1],y[,3]),pr=2)
gnlr3(lyy, "power exp", mu=~matches+burn, pmu=c(2.5,0,0),
	  psh=0,pfam=0.1, delta=1/c(y[,1],y[,3]))

# underflow with other starting values
gnlmm(yy, "Weibull", mu=mu, linear=~matches,
	pmu=zw$coef[1:2], psh=0.7, psd=0.01,nest=gl(11,1,22))
gnlmm(yy, "Weibull", mu=mu, linear=~matches+burn,
	pmu=zw2$coef[1:3], psh=0.9, psd=0.015,nest=gl(11,1,22))
# underflow
#gnlmm(lyy,"normal",mu=mu,linear=~matches,delta=1/c(y[,1],y[,3]),
#	pmu=zn$coef[1:2], psh=-1.2, psd=0.01,nest=gl(11,1,22),points=3)
#gnlmm(lyy, "normal", mu=mu, linear=~matches+burn, psh=-1.8,
#	pmu=zn2$coef[1:3],psd=0.015,nest=gl(11,1,22),delta=1/c(y[,1],y[,3]),
#	points=3)

kalsurv(resp,preg=3.4,pinit=0.1,int="Weibull",psh=1)
print(zw1 <- kalsurv(resp,preg=3.4,pinit=0.1,int="Weibull",psh=1,
	dep="frailty"))
type <- cbind(rep(0,11),rep(1,11))
print(zw2 <- kalsurv(resp,preg=3.4,pinit=0.1,int="Weibull",psh=1,
	dep="frailty",tvc=~type,ptvc=0))
print(zw2b <- kalsurv(resp,preg=c(3.4,0),pinit=0.1,int="Weibull",psh=1,
	dep="frailty",ccov=~y[,5],tvc=~type,ptvc=0))

print(zln1 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log normal",psh=1,
	dep="frailty"))
print(zln2 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log normal",psh=1,
	dep="frailty",tvc=~type,ptvc=0))
print(zln2b <- kalsurv(resp,preg=c(3.4,0),pinit=0.1,int="log normal",psh=1,
	dep="frailty",ccov=~y[,5],tvc=~type,ptvc=0))

print(zll1 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log logistic",psh=1,
	dep="frailty"))
print(zll2 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log logistic",psh=1,
	dep="frailty",tvc=~type,ptvc=0))

print(zlc1 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log Cauchy",psh=1,
	dep="frailty"))
print(zlc2 <- kalsurv(resp,preg=3.4,pinit=0.1,int="log Cauchy",psh=1,
	dep="frailty",tvc=~type,ptvc=0))

if(interactive()){
postscript("grafts.eps",height=5)
par(mfrow=c(1,2))
times <- seq(1,100,by=5)
plot(km(c(y[,1],y[,3]),cens=c(y[,2],y[,4]),gr=matches),main="",xlab="Days",
	xlim=c(0,100))
# independent Weibull
lines(times,1-pweibull(times,exp(zw$coef[3]),exp(zw$coef[1])),lty=3)
#lines(times,1-pweibull(times,exp(zw$coef[3]),exp(zw$coef[1]+zw$coef[2])),lty=2)
# kalsurv Weibull
#lines(times,exp(zw2$coef[3])/(exp(zw2$coef[3])+(times/
#	exp(zw2$coef[1]))^exp(zw2$coef[4])))
# kalsurv log normal
lines(times,exp(zln2$coef[3])/(exp(zln2$coef[3])-
	log(1-pnorm(log(times),zln2$coef[1],exp(zln2$coef[4]/2)))))
lines(times,exp(zln2$coef[3])/(exp(zln2$coef[3])-log(1-pnorm
	(log(times),zln2$coef[1]+zln2$coef[2],exp(zln2$coef[4]/2)))),lty=2)

#lines(sort(y[y[,2]>0,1]),zcr$gamma/
#	(zcr$gamma+cumsum(zcr$inthaz[1:9])),type="l")
#lines(unique(sort(y[,3])),zcr$gamma/(zcr$gamma+cumsum(zcr$inthaz[10:18])),lty=2)

#lines(sort(y[y[,2]>0,1]),zcr$gamma/
#	(zcr$gamma+zcr$fitted[51:59]),type="l")
#lines(unique(sort(y[,3])),zcr$gamma/(zcr$gamma+zcr$fit[105:113]),lty=2)

plot(1:100,exp(zln2$coef[3])*dnorm(log(1:100),zln2$coef[1],exp(zln2$coef[4]/2))
	/(1:100)/(1-pnorm(log(1:100),zln2$coef[1],exp(zln2$coef[4]/2)))
	/(exp(zln2$coef[3])-log(1-pnorm(log(1:100),zln2$coef[1],
	exp(zln2$coef[4]/2)))),type="l",ylim=c(0,0.15),xlab="Days",
	ylab="Intensity function")
lines(1:100,exp(zln2$coef[3])*dnorm(log(1:100),zln2$coef[1]+zln2$coef[2],
	exp(zln2$coef[4]/2))/(1:100)/(1-pnorm(log(1:100),zln2$coef[1]
	+zln2$coef[2],exp(zln2$coef[4]/2)))/(exp(zln2$coef[3])-
	log(1-pnorm(log(1:100),zln2$coef[1]+zln2$coef[2],
	exp(zln2$coef[4]/2)))),lty=2)

#lines(sort(y[y[,2]>0,1]),zcr$gamma*exp(zcr$coef)*zcr$fixed[1:9]/
#	(zcr$gamma+zcr$inthaz[y[,2]>0]))
#lines(sort(y[,3]),zcr$gamma*exp(zcr$coef)*
#	zcr$fixed[c(1,2,3,3,4,5,6,6,7,8,9)+9]/(zcr$gamma+zcr$inthaz),lty=2)
}
