library(event)
library(gnlm)

y <- read.table("grafts.dat",skip=5)
attach(y)
resp <- cbind(y[,1],y[,3])
censor <- cbind(y[,2],y[,4])
burn <- y[,5]
type <- cbind(rep(0,11),rep(1,11))
reps <- rmna(restovec(resp,censor=censor),ccov=tcctomat(burn),
	tvc=tvctomat(type))

# Different intensity functions
print(zcr <- coxre(resp,censor,1:11,est=0.1,stratified=T))
# Proportional intensity functions
coxre(resp,censor,1:11,est=0.1,stratified=F)
# Identical intensity functions
coxre(response(reps)[,1],response(reps)[,2],rep(1:11,rep(2,11)),est=0.1)

coxre(resp,censor,1:11,est=0.1,cov=y[,5],stratified=T)

mu <- function(p,linear) exp(linear)
print(zw <- gnlr(reps,"Weibull",mu=mu,linear=~type,pmu=c(4,-1),psh=0.5))
print(zln2 <- kalsurv(reps,preg=3.4,pinit=0.1,int="log normal",psh=1,
	dep="frailty",tvc=~type,ptvc=0))
print(zln2b <- kalsurv(reps,preg=c(3.4,0),pinit=0.1,int="log normal",psh=1,
	dep="frailty",ccov=~burn,tvc=~type,ptvc=0))

if(interactive()){
postscript("grafts.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
times <- seq(1,100,by=5)
plot(km(c(y[,1],y[,3]),cens=c(y[,2],y[,4]),gr=gl(2,11,22)),main="",xlab="Days",
	xlim=c(0,100))
# independent Weibull
lines(times,1-pweibull(times,exp(zw$coef[3]),exp(zw$coef[1])),lty=3)
lines(times,1-pweibull(times,exp(zw$coef[3]),exp(zw$coef[1]+zw$coef[2])),lty=3)
lines(times,exp(zln2$coef[3])/(exp(zln2$coef[3])-
	log(1-pnorm(log(times),zln2$coef[1],exp(zln2$coef[4]/2)))))
lines(times,exp(zln2$coef[3])/(exp(zln2$coef[3])-log(1-pnorm
	(log(times),zln2$coef[1]+zln2$coef[2],exp(zln2$coef[4]/2)))),lty=2)
legend(40,1,legend=c("Close matches","Poor matches"),lty=1:2,bty="n")
plot(1:100,exp(zln2$coef[3])*dnorm(log(1:100),zln2$coef[1],exp(zln2$coef[4]/2))
	/(1:100)/(1-pnorm(log(1:100),zln2$coef[1],exp(zln2$coef[4]/2)))
	/(exp(zln2$coef[3])-log(1-pnorm(log(1:100),zln2$coef[1],
	exp(zln2$coef[4]/2)))),type="l",ylim=c(0,0.15),xlab="Days",
	ylab="Intensity function")
lines(1:100,exp(zln2$coef[3])*dnorm(log(1:100),zln2$coef[1]+zln2$coef[2],
	exp(zln2$coef[4]/2))/(1:100)/(1-pnorm(log(1:100),zln2$coef[1]
	+zln2$coef[2],exp(zln2$coef[4]/2)))/(exp(zln2$coef[3])-
	log(1-pnorm(log(1:100),zln2$coef[1]+zln2$coef[2],
	exp(zln2$coef[4]/2)))),lty=2)
dev.off()
}
