library(repeated)
library(event)
library(gnlm)

resp <- read.table("ratsurv.dat",skip=6)
y <- cbind(resp[,1],resp[,3],resp[,5])
cens <- cbind(resp[,2],resp[,4],resp[,6])
yy <- cbind(as.vector(t(y)), as.vector(t(cens)))
lyy <- cbind(as.vector(t(log(y))), as.vector(t(cens)))
treat <- matrix(rep(c(0,1,1),50),ncol=3,byrow=T)
tr <- as.vector(t(treat))
delta <- 1/as.vector(t(y))
y <- restovec(y,cens=cens)

mu <- function(p,linear) exp(linear)
gnlr(yy,"expon",pmu=5,mu=mu,linear=~1)
gnlr(yy,"expon",pmu=c(5,0.2),mu=mu,linear=~tr)
gnlr(yy,"Weibull",pmu=5,mu=mu,linear=~1,psh=1)
gnlr(yy,"Weibull",pmu=c(5,0.2),mu=mu,linear=~tr,psh=1)
gnlr(y,"Weibull",pmu=c(5,0.2),mu=mu,linear=~tr,shape=~tr,pshape=c(1,0))
gnlr(yy,"gamma",pmu=5,mu=mu,linear=~1,psh=1)
gnlr(yy,"gamma",pmu=c(5,0.2),mu=mu,linear=~tr,psh=1)
gnlr(lyy,"normal",pmu=5,mu=~1,psh=-1,delta=delta)
gnlr(lyy,"normal",pmu=c(5,0.2),mu=~tr,psh=-1,delta=delta)
gnlr(lyy,"logistic",pmu=1.5,mu=~1,psh=-1,delta=delta)
gnlr(lyy,"logistic",pmu=c(1.5,0.2),mu=~tr,psh=-1,delta=delta)
gnlr(lyy,"Cauchy",pmu=1.5,mu=~1,psh=-1,delta=delta)
gnlr(lyy,"Cauchy",pmu=c(1.5,0.2),mu=~tr,psh=-1,delta=delta)
gnlr(lyy,"Laplace",pmu=1.5,mu=~1,psh=-1,delta=delta)
gnlr(lyy,"Laplace",pmu=c(1.5,0.2),mu=~tr,psh=-1,delta=delta)

kalsurv(y,preg=5,pinit=0.001)
kalsurv(y,preg=6,dep="frailty")
kalsurv(y,preg=6,dep="frailty",tvcov=~treat,ptvc=0)

kalsurv(y,int="Weibull",psh=3.7,preg=5,pinit=0.01)
kalsurv(y,dep="frailty",int="Weibull",psh=4,preg=5)
print(zwf <- kalsurv(y,dep="frailty",int="Weibull",psh=4,preg=5,
	tvcov=~treat,ptvc=0))

kalsurv(y,int="gamma",psh=3,preg=4.7,pinit=0.001)
kalsurv(y,dep="frailty",int="gamma",psh=3,preg=2)
kalsurv(y,dep="frailty",int="gamma",psh=7,preg=4.7,tvcov=~treat,ptvc=0.23)

kalsurv(y,int="log normal",psh=0.23,preg=5,pinit=0.001)
kalsurv(y,dep="frailty",int="log normal",psh=0.1,preg=4.8,pinit=2)
kalsurv(y,dep="frailty",int="log normal",psh=0.2,preg=5,pinit=2,tvcov=~treat,
	ptvc=0)

kalsurv(y,int="log logistic",psh=0.2,pinit=0.01,preg=5)
kalsurv(y,dep="frailty",int="log logistic",psh=0.2,pinit=0.1,preg=5)
kalsurv(y,dep="frailty",int="log logistic",psh=0.2,pinit=0.1,
	preg=5,tvcov=~treat,ptvc=0)

kalsurv(y,int="log Cauchy",psh=0.2,pinit=1,preg=5)
kalsurv(y,dep="frailty",int="log Cauchy",psh=0.2,pinit=1,preg=5)
kalsurv(y,dep="frailty",int="log Cauchy",psh=0.2,pinit=0.1,preg=5,
	tvcov=~treat,ptvc=0)

kalsurv(y,int="log Laplace",psh=0.085,pinit=0.001,preg=4.7)
#kalsurv(y,dep="frailty",int="log Laplace",psh=0.1,pinit=20,preg=4.6)
#kalsurv(y,dep="frailty",int="log Laplace",psh=0.005,pinit=0.1,
#	preg=4.8,tvcov=~treat,ptvc=0.23)

mu <- function(p) exp(p[1])
gnlmm(yy,"expon",pmu=5.8,mu=mu,nest=gl(50,3,150),psd=0.1)
gnlmm(yy,"Weibull",pmu=5,mu=mu,psh=1,nest=gl(50,3,150),
	points=3,psd=0.1)
gnlmm(yy,"gamma",pmu=5.8,mu=mu,psh=1,nest=gl(50,3,150),
	points=3,psd=0.1)
gnlmm(lyy,"normal",pmu=5,psh=-1.5,delta=1/response(y),
	nest=gl(50,3,150),points=3,psd=0.1)

mu <- function(p) exp(p[1]+p[2]*tr)
gnlmm(yy,"expon",pmu=c(5.8,0.8),mu=mu,nest=gl(50,3,150),psd=0.08)
gnlmm(yy,"Weibull",pmu=c(4.7,0.2),mu=mu,psh=1,nest=gl(50,3,150),
	points=3,psd=0.1)
gnlmm(yy,"gamma",pmu=c(4.7,0.2),mu=mu,psh=1.9,nest=gl(50,3,150),
	points=3,psd=0.1)
#gnlmm(lyy,"normal",pmu=c(4.7,0.2),mu=mu,psh=-1.5,delta=1/response(y),
#	nest=gl(50,3,150),points=3,psd=0.1)


if(interactive()){
par(mfrow=c(1,2))
plot(km(response(y),as.vector(t(cens)),group=tr),main="",xlab="Weeks",
	ylab="Survival function",xlim=c(0,104))
lines(1:104,1-((1:104)/exp(z$coef[1]))^exp(z$coef[3]))
lines(1:104,1-((1:104)/exp(z$coef[1]+z$coef[2]))^exp(z$coef[3]),lty=2)
plot(1:104,exp(hweibull(1:104,exp(z$coef[3]),exp(z$coef[1]))),type="l",
	xlab="Weeks",ylab="Intensity")
lines(1:104,exp(hweibull(1:104,exp(z$coef[3]),exp(z$coef[1]+z$coef[2]))),lty=2)
postscript("ratsurv.eps",height=5)
par(mfrow=c(1,2))
plot(km(response(y),as.vector(t(cens)),group=tr),main="",xlab="Weeks",
	ylab="Survival function",xlim=c(0,104))
lines(1:104,1-((1:104)/exp(zwf$coef[1]))^exp(zwf$coef[4]))
lines(1:104,1-((1:104)/exp(zwf$coef[1]+zwf$coef[2]))^exp(zwf$coef[4]),lty=2)
plot(1:104,exp(hweibull(1:104,exp(zwf$coef[4]),exp(zwf$coef[1]))),type="l",
	xlab="Weeks",ylab="Intensity")
lines(1:104,exp(hweibull(1:104,exp(zwf$coef[4]),exp(zwf$coef[1]+zwf$coef[2]))),
	lty=2)
}
